@@ -1,5 +1,7 @@
 import dataclasses
+import os
 import sys
+from contextlib import contextmanager
 from dataclasses import dataclass
 from enum import Enum, unique
 from pathlib import Path
@@ -9,6 +11,8 @@ from typing import (
     AnyStr,
     Callable,
     Iterable,
+    Iterator,
+    Literal,
     Optional,
     Sequence,
     TypeVar,
@@ -21,15 +25,16 @@ import pluggy
 import tomli_w
 
 from robotcode.core.utils.dataclasses import as_dict, as_json
+from robotcode.core.utils.path import same_file
 
 __all__ = [
-    "hookimpl",
-    "CommonConfig",
-    "pass_application",
     "Application",
-    "UnknownError",
-    "OutputFormat",
     "ColoredOutput",
+    "CommonConfig",
+    "OutputFormat",
+    "UnknownError",
+    "hookimpl",
+    "pass_application",
 ]
 
 F = TypeVar("F", bound=Callable[..., Any])
@@ -64,6 +69,8 @@ class OutputFormat(str, Enum):
 class CommonConfig:
     config_files: Optional[Sequence[Path]] = None
     profiles: Optional[Sequence[str]] = None
+    root: Optional[Path] = None
+    no_vcs: bool = False
     dry: bool = False
     verbose: bool = False
     colored_output: ColoredOutput = ColoredOutput.AUTO
@@ -266,18 +273,21 @@ class Application:
         text_or_generator: Union[Iterable[str], Callable[[], Iterable[str]], str],
         color: Optional[bool] = None,
     ) -> None:
-        if not self.config.pager:
-            text = (
-                text_or_generator
-                if isinstance(text_or_generator, str)
-                else "".join(text_or_generator() if callable(text_or_generator) else text_or_generator)
-            )
-            click.echo(text, color=color if color is not None else self.colored)
-        else:
-            click.echo_via_pager(
-                text_or_generator,
-                color=color if color is not None else self.colored,
-            )
+        try:
+            if not self.config.pager:
+                text = (
+                    text_or_generator
+                    if isinstance(text_or_generator, str)
+                    else "".join(text_or_generator() if callable(text_or_generator) else text_or_generator)
+                )
+                click.echo(text, color=color if color is not None else self.colored)
+            else:
+                click.echo_via_pager(
+                    text_or_generator,
+                    color=color if color is not None else self.colored,
+                )
+        except OSError:
+            pass
 
     def keyboard_interrupt(self) -> None:
         self.verbose("Aborted!", file=sys.stderr)
@@ -287,5 +297,34 @@ class Application:
         self.verbose(f"Exit with code {code}")
         sys.exit(code)
 
+    @contextmanager
+    def chdir(self, path: Union[str, Path, None]) -> Iterator[Optional[Path]]:
+        old_dir: Optional[Path] = Path.cwd()
+
+        if path is None or (old_dir and same_file(path, old_dir)):
+            self.verbose(f"no need to change directory to {path}")
+            old_dir = None
+        else:
+            if path:
+                self.verbose(f"Changing directory to {path}")
+
+                os.chdir(path)
+
+        try:
+            yield old_dir
+        finally:
+            if old_dir is not None:
+                self.verbose(f"Changing directory back to {old_dir}")
+
+                os.chdir(old_dir)
+
+    @contextmanager
+    def save_syspath(self) -> Iterator[Literal[None]]:
+        self._syspath = sys.path[:]
+        try:
+            yield None
+        finally:
+            sys.path = self._syspath
+
 
 pass_application = click.make_pass_decorator(Application, ensure=True)
